' LinkedTab_AutoClose_Handler:
' Revision: v1.2.2 (vb)
' (c) 2015 steje
'
' This is a script for written for Directory Opus v11.
' See http://www.gpsoft.com.au/redirect.asp?page=scripts for development information.

' =====================================================================================
' ===========================   EVENT HANDLER: OnCloseTab   ===========================
'
' The purpose of this script is to provide users with the option of having linked tabs
' automatically be closed whenever the tabs which they are linked to are closed...
'
' The scripts behavior can be enabled/disabled by either of the following settings:
'
' Script configuration:          The scripts listing under Preferences
' Script configuration option:   Setting the Always_On option to True/False
' An Opus environment variable:  linkedtab_autoclose
'
' The first setting is controlled by checking or unchecking the scripts listing in Prefs
' The second setting is controlled via the Always_On option under the scripts listing in Prefs
' The third setting can be controlled via any standard button or hotkey in Opus that
' toggles an environment variable of either global, lister or source tab scope, e.g.:
'
'                        @toggle:if $glob:linkedtab_autoclose
'
'                        @ifset:$glob:linkedtab_autoclose
'                        @set glob:linkedtab_autoclose
'
'                        @ifset:else
'                        @set glob:linkedtab_autoclose=true
'
' =====================================================================================

Option Explicit
Dim SCRIPT_DEBUG
SCRIPT_DEBUG = False


'//////////////////////////////////////////////////////////////////////////////////////////////////
' Called by Directory Opus to initialize the script
Function OnInit(ByRef initData)

   DOpus.Output("Initializing...")

   ' Provide basic information about the Script
   initData.min_version = "11.16"
   initData.name = "LinkedTab_AutoClose_Handler"
   initData.desc = "Event Handler for the OnCloseTab event. Used to auto-close a folder " &_
                   "tab that is linked to the tab which the user is closing."
   initData.copyright = "(c) 2015 steje"
   initData.version = "v1.2.2 (vb)"
   initData.default_enable = True

   '////////////////////////////////////////////////
   ' The following options are user configurable via the Configure button under the scripts listing in Prefs
   '////////////////////////////////////////////////
   ' Set Always_On to True in order to enable script execution without the use of environment variables
   initData.config.Always_On = True
   '////////////////////////////////////////////////
   ' Set DEBUG flag to True in order to enable logging messages to the Opus Output Window
   initData.config.DEBUG = False
   '////////////////////////////////////////////////
   ' Set DEBUG_CLEAR flag to True in order to clear log messages from the Opus Output Window between script runs
   initData.config.DEBUG_CLEAR = False
   '////////////////////////////////////////////////
   ' Set QualKey to the qualifier key that you want to ENABLE the scripts execution
   initData.config.QualKey = DOpus.NewVector(0, "none", "shift", "lwin", "rwin")
   '////////////////////////////////////////////////
   ' Set QualKey_Disable to the qualifier key that you want to DISABLE the scripts execution
   initData.config.QualKey_Disable = DOpus.NewVector(0, "none", "shift", "lwin", "rwin")
   '////////////////////////////////////////////////
   ' Set descriptions for all script options
   initData.config_desc = DOpus.NewMap("Always_On", "Set this option to True in order to enable script execution without the use of environment variables.", _
                                       "DEBUG", "Set this option to True to enable logging to the Opus script log.", _
                                       "DEBUG_CLEAR", "Set this option to True clear messages logged to the Opus script log between script runs.", _
                                       "QualKey", "Set this option to the qualifier key that you want to ENABLE the scripts execution.", _
                                       "QualKey_Disable", "Set this option to the qualifier key that you want to DISABLE the scripts execution.")

End Function


'//////////////////////////////////////////////////////////////////////////////////////////////////
' Called when a folder tab is closed
Function OnCloseTab(ByRef closeTabData)
   Dim objCmd

   Set objCmd = DOpus.NewCommand
   If (objCmd.IsSet("$glob:SCRIPT_DEBUG")) Then SCRIPT_DEBUG = True
   If ((Script.config.DEBUG) Or (SCRIPT_DEBUG)) And (Script.config.DEBUG_CLEAR) Then DOpus.ClearOutput
   'logMsg("OnCloseTab()")

   logMsg("")
   logMsg("----------------------------------------------------------------")
   logMsg("OnCloseTab:  " & closeTabData.tab.path)
   logMsg("----------------------------------------------------------------")
   If (executeScript(closeTabData)) Then
      ' Check if the tab is NOT linked and if so - nothing to do, exit...
      If (closeTabData.tab.linktab = 0) Then
         logMsg("Tab is not linked, exit...")
      Else
         objCmd.RunCommand("Go TABCLOSE=" & closeTabData.tab.linktab & " NOSCRIPT")
      End If
   End If

   Set objCmd = Nothing

End Function


'//////////////////////////////////////////////////////////////////////////////////////////////////
' Check for various things that determine if the script should run or not
Function executeScript(ByRef tabData)
   Dim QUALKEY
   Dim objCmd
   'logMsg("executeScript()")

   executeScript = False

   ' Check for any of the script options or environment variables that enable the scripts execution
   Set objCmd = DOpus.NewCommand
   If (Script.config.Always_On) Then
      'logMsg("Script is set to 'always on'")
   ElseIf(objCmd.IsSet("$glob:linkedtab_autoclose")) Then
      'logMsg("[linkedtab_autoclose] is set: [global]")
   ElseIf (objCmd.IsSet("$lst:linkedtab_autoclose")) Then
      'logMsg("[linkedtab_autoclose] is set: [lister]")
   ElseIf (objCmd.IsSet("$src:linkedtab_autoclose")) Then
      'logMsg("[linkedtab_autoclose] is set: [source tab]")
   Else
      logMsg("Not enabled, exit...")
      Set objCmd = Nothing
      Exit Function
   End If

   ' Check for any qualifier key that might have been used and recast as int we can test against vector values
   If (tabData.qualifiers = "none") Then
      QUALKEY = 0
   ElseIf (tabData.qualifiers = "shift") Then
      QUALKEY = 1
   ElseIf (tabData.qualifiers = "lwin") Then
      QUALKEY = 2
   ElseIf (tabData.qualifiers = "rwin") Then
      QUALKEY = 3
   End If

   ' Check for DISABLING qualifier key settings
   If ((QUALKEY = Script.config.QualKey_Disable) And (QUALKEY > 0)) Then
      logMsg("The qualifier key to DISABLE was used, exit...")
      Set objCmd = Nothing
      Exit Function
   End If

   ' Check for ENABLING qualifier key settings
   If Not (QUALKEY = Script.config.QualKey) Then
      logMsg("No valid qualifier key was used, exit...")
      Set objCmd = Nothing
      Exit Function
   End If

   executeScript = True
   Set objCmd = Nothing

End Function


'//////////////////////////////////////////////////////////////////////////////////////////////////
' Subroutine that uses DEBUG variables to control whether logging is performed or not
Sub logMsg(ByRef message)

   If ((Script.config.DEBUG) Or (SCRIPT_DEBUG)) Then DOpus.Output(message)

End Sub
